if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database 1> /dev/null 2> /dev/null
fi
( cd usr/bin ; rm -rf abiword )
( cd usr/bin ; ln -sf AbiWord-2.4 abiword )
( cd usr/share/icons ; rm -rf abiword_48.png )
( cd usr/share/icons ; ln -sf ../pixmaps/abiword_48.png abiword_48.png )
